==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/form-editor/scrollbar.h <==
//$Id: scrollbar.h,v 1.9 2001/11/15 20:22:00 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_SCROLLBAR_H
#define GUIKACHU_FORM_EDITOR_SCROLLBAR_H

namespace Guikachu
{
    namespace Widgets
    {
	class ScrollBar;
    }
}

#include "widget.h"
#include "resizeable.h"

#include "scrollbar-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class ScrollBar: public Widget
	{
	    GUI::FormEditor::ScrollBarProperties *editor;

	    SigC::Signal0<void> manual_width_changed;
	    
	public:
	    ScrollBar (Resources::Form   *owner,
		       const std::string &id);
	    virtual ~ScrollBar ();
	    
	    virtual Type get_type () const { return WIDGET_SCROLLBAR; };
	    
	    virtual GUI::FormEditor::CanvasItem *create_canvas_item (GUI::FormEditor::Form *form);
	    virtual Gtk::Widget                 *create_editor ();

	    Property<bool> usable;
	    Property<int>  min_value, max_value, value, page_size;

	    Property<int>  width;
	    Property<bool> manual_width;
	    Property<int>  height;
	    
	    int get_display_width () const;

	protected:
	    int get_auto_width () const;

	private:
	    void manual_width_cb ();
	    
	private:
	    // Persistance
	    virtual bool load (StorageNode &node);
	    virtual void save (StorageNode &node) const;
	    virtual void save_rcp (std::ostream &ostr) const;

	private:
	    void update ();
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_SCROLLBAR_H */

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/form-editor/scrollbar.h <==
//$Id: scrollbar.h,v 1.19 2003/06/30 14:07:58 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_SCROLLBAR_H
#define GUIKACHU_FORM_EDITOR_SCROLLBAR_H

#include "widget.h"
#include "auto-resizeable.h"

namespace Guikachu
{
    namespace Widgets
    {
	class ScrollBar: public Widget,
			 public AutoWidth
	{
	public:
	    ScrollBar (Resources::Form *owner, const std::string &id, serial_t serial);
	    
	    Type get_type () const { return WIDGET_SCROLLBAR; };
	    void apply_visitor (WidgetVisitor &visitor) { visitor.visit_widget (this); };
	    
	    Property<bool> usable;
	    Property<int>  min_value, max_value, value, page_size;
	    
	protected:
	    int get_auto_width () const;

	private:
	    void update ();
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_SCROLLBAR_H */
